/*
 * Copyright (C) 2024 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include <scene.h>

#include <fstream>

enum FeatureStatus : int { UNKNOWN = -1, AVAILABLE = 0, NOT_INSTALLED, NOT_SUPPORTED };

// 模型名称：https://gitlab2.kylin.com/zouxiaoyi/ondevice-embedding-models
const char* TEXT_MODEL_PATH = "text_model_path";
const char* VISION_MODEL_PATH = "vision_model_path";
const char* VISION_TXT_MODEL_PATH = "vision_text_model_path";
const char* NLP_ONDEVICE_MODEL_PATH = "nlp_ondevice_model_path";

Response handleGetFeatureStatus(const Request& request) {
    // 默认都支持模型，不会返回 NOT_SUPPORTED

    std::ifstream textModelFile(Configuration::getString(TEXT_MODEL_PATH));
    if (!textModelFile.good()) {
        PRINT_WARN("HandleGetFeatureStatus: model file not exist, %s.\n",
                   Configuration::getString(TEXT_MODEL_PATH).c_str());
        return Response::success(nlohmann::json{{"result", NOT_INSTALLED}});
    }
    textModelFile.close();

    std::ifstream visionModelFile(Configuration::getString(VISION_MODEL_PATH));
    if (!visionModelFile.good()) {
        PRINT_WARN("HandleGetFeatureStatus: model file not exist, %s.\n",
                   Configuration::getString(VISION_MODEL_PATH).c_str());
        return Response::success(nlohmann::json{{"result", NOT_INSTALLED}});
    }
    visionModelFile.close();

    std::ifstream visionTxtModelFile(Configuration::getString(VISION_TXT_MODEL_PATH));
    if (!visionTxtModelFile.good()) {
        PRINT_WARN("HandleGetFeatureStatus: model file not exist, %s.\n",
                   Configuration::getString(VISION_TXT_MODEL_PATH).c_str());
        return Response::success(nlohmann::json{{"result", NOT_INSTALLED}});
    }
    visionTxtModelFile.close();

    return Response::success(nlohmann::json{{"result", AVAILABLE}});
}

REGISTER_SERVICE_HANDLER("getFeatureStatus", handleGetFeatureStatus)
