/*
 * Copyright (C) 2024 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include <gio/gio.h>

#include <cstdlib>
#include <iostream>

void callback(GDBusConnection* conn, const gchar* sender_name, const gchar* object_path, const gchar* interface_name,
              const gchar* signal_name, GVariant* parameters, gpointer user_data) {
    // 这里的user_data是在g_dbus_connection_signal_subscribe时设置的任意对象指针
    // 被设置的指针会原封不动在callback返回
    // 例如可以将this放进去
    // 然后在callback里强转成对应类型使用

    GVariant* var = g_variant_get_child_value(parameters, 0);
    const gchar* path = g_variant_get_string(var, NULL);
    printf("callback data: %s\n", path);
    free(path);
}

int main() {
    GMainLoop* loop = g_main_loop_new(nullptr, FALSE);
    GDBusConnection* connection = nullptr;
    GError* error = nullptr;

    const std::string serverUnixPath =
        "unix:abstract=/tmp/.kylin-ai-business-unix/" + std::to_string(getuid()) + "/DataManagement.sock";
    const std::string objectPath = "/com/kylin/AiBusiness/DataManagement";
    const std::string interfaceName = "com.kylin.AiBusiness.DataManagement";

    connection = g_dbus_connection_new_for_address_sync(
        serverUnixPath.c_str(), G_DBUS_CONNECTION_FLAGS_AUTHENTICATION_CLIENT, nullptr, nullptr, &error);
    if (connection == nullptr) {
        printf("Error connecting to D-Bus address %s: %s\n", serverUnixPath.c_str(), error->message);
        g_error_free(error);
        return EXIT_FAILURE;
    }

    guint sub_id = g_dbus_connection_signal_subscribe(connection, nullptr, interfaceName.c_str(), "FileIndexFinished",
                                                      objectPath.c_str(), nullptr, G_DBUS_SIGNAL_FLAGS_NONE, callback,
                                                      nullptr, nullptr);

    std::cout << "监听中... 按 Ctrl+C 退出" << std::endl;
    g_main_loop_run(loop);

    // 清理
    g_dbus_connection_signal_unsubscribe(connection, sub_id);
    g_object_unref(connection);
    g_main_loop_unref(loop);

    return EXIT_SUCCESS;
}
